<!--
* CoreUI - Free Bootstrap Admin Template
* @version v2.0.0-beta.0
* @link https://coreui.io
* Copyright (c) 2018 creativeLabs Łukasz Holeczek
* Licensed under MIT (https://coreui.io/license)
-->
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, shrink-to-fit=no">

    <link rel="shortcut icon" href="{{  url_for('static', filename='images/molssi-favicon.jpg') }}">
    <title>SEAMM Dashboard</title>

    <!-- Main styles for this application-->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='node_modules/datatables.net-bs4/css/dataTables.bootstrap4.min.css') }}"/>
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='node_modules/datatables.net-buttons-bs4/css/buttons.bootstrap4.min.css') }}"/>
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='node_modules/datatables.net-select-dt/css/select.dataTables.min.css') }}"/> 
    <link href="{{ url_for('static', filename='css/custom.css') }}" rel="stylesheet">
  </head>

  <body class="app header-fixed sidebar-fixed aside-menu-fixed sidebar-lg-show">
    <header class="app-header navbar">
      <button class="navbar-toggler sidebar-toggler d-lg-none mr-auto" type="button" data-toggle="sidebar-show">
        <span class="navbar-toggler-icon"></span>
      </button>
      <a class="navbar-brand" href="#">
        <img class="navbar-brand-full" src="{{ url_for('static', filename='images/MolSSI-Logo-xl.jpg') }}"  height="50" alt="MolSSI">
        <img class="navbar-brand-minimized" src="{{ url_for('static', filename='images/molssi-favicon.jpg') }}" width="30" height="30" alt="MolSSI Logo">
      </a>
      <ul class="navbar-nav">
        <li class="nav-item">
        </li>
    </ul>
      <ul class="navbar-nav" id="login-info">
      </ul>
    </header>
    <div class="app-body">
      <div class="sidebar">
        <nav class="sidebar-nav">
          <ul class="nav">
            <li class="nav-item">
              <a class="nav-link" href="main.html">
                <i class="nav-icon fas fa-tachometer-alt"></i> Dashboard
              </a>
            </li>
              <li class="nav-item">
              <a class="nav-link" href="jobs">
                <i class="nav-icon fas fa-list"></i> Jobs List</a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="flowcharts">
                <i class="nav-icon fas fa-project-diagram"></i> Flowcharts List</a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="projects">
                <i class="nav-icon fas fa-object-group"></i> Projects List</a>
            </li>
            <li class="nav-title">Actions</li>
              <li class="nav-item">
              <a class="nav-link" href="#">
                <i class="nav-icon fas fa-puzzle-piece"></i> Submit Job</a>
            </li>
            <li class="nav-item">
              <a class="nav-form" href="/jobs/import">
                <i class="nav-icon fas fa-cloud-upload-alt"></i> Import Job</a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="#">
                <i class="nav-icon fas fa-download"></i> Export DB</a>
            </li>
            <li class="nav-title">Server</li>
            <li class="nav-item nav-dropdown">
              <a class="nav-link nav-dropdown-toggle" href="#">
                <i class="nav-icon fas fa-cogs"></i> Settings</a>
              <ul class="nav-dropdown-items">
                <li class="nav-item">
                  <a class="nav-link" href="#">
                    <i class="nav-icon far fa-edit"></i> Edit</a>
                </li>
              </ul>
            </li>
          </ul>
        </nav>
        <button class="sidebar-minimizer brand-minimizer" type="button"></button>
      </div>
      <main class="main">
        <div class="container-fluid vh-100 mt-3">
            {% for message in get_flashed_messages(true) %}
              {% if message[0] == "public" %}
                <div class="alert alert-info">
                    {{ message[1] }}
                </div>
              {% elif message[0] == "success" %}
              <div class="alert alert-success">
                <button type="button" class="close" data-dismiss="alert">&times;</button>
                  {{ message[1] }}
              </div>
              {% else %}
                <div class="alert alert-warning">
                  <button type="button" class="close" data-dismiss="alert">&times;</button>
                  {{ message[1] }}
              </div>
              {% endif %}
            {% endfor %}
          <div id="ui-view" class="vw-100"></div>
      </main>
    </div>
    <footer class="app-footer">
      <div>
        <a href="http://molssi.org">MolSSI</a>
        <span>&copy; 2018-2021 The Molecular Sciences Software Institute.</span>
      </div>
    </footer>
    <!-- Bootstrap and necessary plugins-->
    <script src="{{ url_for('static', filename='node_modules/jquery/dist/jquery.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/jquery-csv/src/jquery.csv.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/popper.js/dist/umd/popper.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/bootstrap/dist/js/bootstrap.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/pace-progress/pace.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/perfect-scrollbar/dist/perfect-scrollbar.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/@coreui/coreui/dist/js/coreui.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/cytoscape/dist/cytoscape.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/@fortawesome/fontawesome-free/js/all.min.js')}}"></script>
    
    <!-- extras -->
    <script src="{{ url_for('static', filename='node_modules/datatables.net/js/jquery.dataTables.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/datatables.net-dt/js/dataTables.dataTables.min.js') }}"></script> 
    <script src="{{ url_for('static', filename='node_modules/datatables.net-bs4/js/dataTables.bootstrap4.min.js') }}"></script> 
    <script src="{{ url_for('static', filename='node_modules/datatables.net-buttons/js/dataTables.buttons.min.js') }}"></script>
    <script src="{{ url_for('static', filename='node_modules/datatables.net-select/js/dataTables.select.min.js') }}"></script>
    <!--Page monitor and status-->
    <script src="{{ url_for('static', filename='js/setup.js') }}"></script>

    <script>
      $('#ui-view').ajaxLoad();
    </script>
  </body>
</html>
