
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2022-03-18T10:28:01-0400",
 "dirty": false,
 "error": null,
 "full-revisionid": "71e43c5989e051e0d3bac667af4a94a2d6215d7c",
 "version": "2022.3.18"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
